@@ -29,7 +29,7 @@ foreach ($attributes as $key => $values) {
 
 $nameid = $session->getNameID();
 $_SERVER['REMOTE_USER'] = $nameid['value'];
-$_SERVER['REMOTE_USER_DATA'] = base64_encode($data);
+$_SERVER['REMOTE_USER_DATA'] = $data;
 
 if ($config->getValue('logout.cookies')) {
     $loggedin = true;
